/***************************************************************************
 *   Copyright (C) 2004 by Rick L. Vinyard, Jr.                            *
 *   rvinyard@cs.nmsu.edu                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Lesser General Public License as        *
 *   published by the Free Software Foundation version 2.1.                *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
 ***************************************************************************/
#include "boxed.h"

using namespace Papyrus;

Boxed::Boxed()
 : Group()
{
  m_box = Rectangle::create();
  m_box->outline().set_pattern( Cairo::SolidPattern::create_rgba(0.0, 0.0, 0.0, 0.8) );
  m_box->outline().set_width(3);
}

Boxed::pointer Boxed::create() {
  return Boxed::pointer( new Boxed( ) );
}

Boxed::~Boxed()
{
}

Rectangle::pointer Boxed::get_box( )
{
  return m_box;
}

void Boxed::update_extents()
{
  double x, y, w, h, offset = 0.0, offset_2, offset_4;
  this->rebuild_extents();
  this->extents().xywh( x, y, w, h );
  if (m_box->use_outline())
    offset = m_box->outline().width();
  offset_2 = 2.0 * offset;
  offset_4 = 4.0 * offset;
  m_box->set_xywh( x-offset, y-offset, w+offset_2, h+offset_2 );
  this->set_extents( Region( x-offset_2, y-offset_2, w+offset_4, h+offset_4 ) );
  this->need_redraw();
}

void Boxed::draw( Cairo::RefPtr< Cairo::Context > cairo )
{
  // we don't need to draw the box if there are no children
  // this prevents us from drawing a zero size box (point) with a border
  if ( m_children.size() > 0 )
    m_box->render(cairo);
  Group::draw(cairo);
}

